@@ -103,7 +103,7 @@ int fnotify_event_init(void)
  *  fnotify_event_free()
  *	free event info
  */
-void fnotify_event_free(void *data)
+static void fnotify_event_free(void *data)
 {
 	fnotify_fileinfo_t *fileinfo = (fnotify_fileinfo_t *)data;
 
@@ -186,11 +186,11 @@ int fnotify_event_add(
 			    (!strcmp(filename, "/sys/power/wake_lock") ||
 			     !strcmp(filename, "/sys/power/wake_unlock"))) {
 				fnotify_wakelock_info_t	*wakelock_info;
-				link_t	*l;
+				link_t	*wl;
 				bool	found = false;
 
-				for (l = fnotify_wakelocks.head; l; l = l->next) {
-					wakelock_info = (fnotify_wakelock_info_t *)l->data;
+				for (wl = fnotify_wakelocks.head; wl; wl = wl->next) {
+					wakelock_info = (fnotify_wakelock_info_t *)wl->data;
 					if (wakelock_info->proc == p) {
 						found = true;
 						break;
@@ -224,11 +224,11 @@ int fnotify_event_add(
 				wakelock_info->total++;
 			} else {
 				fnotify_fileinfo_t *fileinfo;
-				link_t	*l;
+				link_t	*fl;
 				bool	found = false;
 
-				for (l = fnotify_files.head; l; l = l->next) {
-					fileinfo = (fnotify_fileinfo_t *)l->data;
+				for (fl = fnotify_files.head; fl; fl = fl->next) {
+					fileinfo = (fnotify_fileinfo_t *)fl->data;
 					if ((metadata->mask == fileinfo->mask) &&
 					    (!strcmp(fileinfo->filename, filename))) {
 						found = true;
@@ -270,8 +270,8 @@ int fnotify_event_add(
  */
 static int fnotify_event_cmp_count(const void *data1, const void *data2)
 {
-	fnotify_fileinfo_t *info1 = (fnotify_fileinfo_t *)data1;
-	fnotify_fileinfo_t *info2 = (fnotify_fileinfo_t *)data2;
+	const fnotify_fileinfo_t *info1 = (const fnotify_fileinfo_t *)data1;
+	const fnotify_fileinfo_t *info2 = (const fnotify_fileinfo_t *)data2;
 
 	return info2->count - info1->count;
 }
@@ -282,8 +282,8 @@ static int fnotify_event_cmp_count(const void *data1, const void *data2)
  */
 static int fnotify_event_cmp_io_ops(const void *data1, const void *data2)
 {
-	io_ops_t *io_ops1 = (io_ops_t *)data1;
-	io_ops_t *io_ops2 = (io_ops_t *)data2;
+	const io_ops_t *io_ops1 = (const io_ops_t *)data1;
+	const io_ops_t *io_ops2 = (const io_ops_t *)data2;
 
 	return io_ops2->total - io_ops1->total;
 }
@@ -294,8 +294,8 @@ static int fnotify_event_cmp_io_ops(const void *data1, const void *data2)
  */
 static int fnotify_wakelock_cmp_count(const void *data1, const void *data2)
 {
-	fnotify_wakelock_info_t *w1 = (fnotify_wakelock_info_t *)data1;
-	fnotify_wakelock_info_t *w2 = (fnotify_wakelock_info_t *)data2;
+	const fnotify_wakelock_info_t *w1 = (const fnotify_wakelock_info_t *)data1;
+	const fnotify_wakelock_info_t *w2 = (const fnotify_wakelock_info_t *)data2;
 
 	return w2->total - w1->total;
 }
