@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <pthread.h>
 #include <ctype.h>
+#include <math.h>
 #include <errno.h>
 #include <sys/fanotify.h>
 #include <sys/ptrace.h>
@@ -130,9 +131,9 @@ static void show_usage(void)
  */
 static int parse_pid_list(char *arg, list_t *pids)
 {
-	char *str, *token, *saveptr = NULL;
+	char *str, *token;
 
-	for (str = arg; (token = strtok_r(str, ",", &saveptr)) != NULL; str = NULL) {
+	for (str = arg; (token = strtok(str, ",")) != NULL; str = NULL) {
 		if (isdigit(token[0])) {
 			proc_info_t *p;
 			pid_t pid;
@@ -201,7 +202,7 @@ static int json_write(json_object *obj, const char *filename)
  *  exec_executable()
  *	exec a program
  */
-pid_t exec_executable(const char *opt_username, const char *path, char **argv)
+static pid_t exec_executable(const char *opt_username, const char *path, char **argv)
 {
 	uid_t uid;
 	gid_t gid;
@@ -567,10 +568,11 @@ int main(int argc, char **argv)
 
 	while ((procs_traced > 0) &&
 	       keep_running &&
-	       (opt_duration_secs == DURATION_RUN_FOREVER || timeval_to_double(&duration) > 0.0)) {
+	       (FLOAT_CMP(opt_duration_secs, DURATION_RUN_FOREVER)||
+		timeval_to_double(&duration) > 0.0)) {
 
 		struct timeval *duration_ptr =
-			opt_duration_secs == DURATION_RUN_FOREVER ? NULL : &duration;
+			FLOAT_CMP(opt_duration_secs, DURATION_RUN_FOREVER) ? NULL : &duration;
 #if FNOTIFY_SUPPORTED
 		fd_set rfds;
 		FD_ZERO(&rfds);
