@@ -18,8 +18,6 @@
  * Author: Colin Ian King <colin.king@canonical.com>
  */
 
-int procs_traced = 0;
-
 #define _GNU_SOURCE
 
 #include <stdio.h>
@@ -81,6 +79,8 @@ typedef enum {
 	SYSCALL_UNKNOWN
 } syscall_call_state;
 
+int procs_traced = 0;
+
 static pthread_t syscall_tracer;
 static long int syscall_count = 0;
 static int info_emit = false;
@@ -267,11 +267,11 @@ static void syscall_poll_generic_ret(json_object *j_obj, const syscall_t *sc, co
 		/* Timed out? */
 		if (ret->ret == 0) {
 			/* And the timeout time was zero, we're abusing the poll */
-			if (ret->timeout == 0.0) {
+			if (FLOAT_CMP(ret->timeout, 0.0)) {
 				zero_timeouts++;
 				/* And if the previous poll was also abusive.. */
 				if (prev_ret == 0) {
-					if (prev_timeout == 0.0) {
+					if (FLOAT_CMP(prev_timeout, 0.0)) {
 						/* somebody is polling hard and wasting cycles */
 						zero_timeout_repeats++;
 					} else {
@@ -736,8 +736,8 @@ static inline unsigned long hash_syscall_context(const pid_t pid)
  */
 static int syscall_count_cmp(const void *data1, const void *data2)
 {
-	syscall_info_t *s1 = (syscall_info_t *)data1;
-	syscall_info_t *s2 = (syscall_info_t *)data2;
+	const syscall_info_t *s1 = (const syscall_info_t *)data1;
+	const syscall_info_t *s2 = (const syscall_info_t *)data2;
 
 	if (s1->proc->pid == s2->proc->pid)
 		return s2->count - s1->count;
@@ -892,7 +892,7 @@ static void syscall_count_timeout(
 			s->poll_max = timeout;
 	}
 
-	if (timeout == 0.0) {
+	if (FLOAT_CMP(timeout, 0.0)) {
 		s->poll_zero++;
 		s->poll_too_low++;
 		return;
@@ -1399,8 +1399,8 @@ static void syscall_munmap_args(
  */
 static int syscall_sync_cmp(const void *d1, const void *d2)
 {
-	syscall_sync_info_t *s1 = (syscall_sync_info_t *)d1;
-	syscall_sync_info_t *s2 = (syscall_sync_info_t *)d2;
+	const syscall_sync_info_t *s1 = (const syscall_sync_info_t *)d1;
+	const syscall_sync_info_t *s2 = (const syscall_sync_info_t *)d2;
 
 	return s2->total_count - s1->total_count;
 }
@@ -1627,7 +1627,7 @@ static void syscall_recvfrom_ret(
  */
 static int syscall_wakelock_cmp(const void *data1, const void *data2)
 {
-	return strcmp((char *)data1, (char *)data2);
+	return strcmp((const char *)data1, (const char *)data2);
 }
 
 /*
@@ -1645,7 +1645,7 @@ static inline double syscall_timeval_to_double(struct timeval *tv)
  *  syscall_wakelock_names_by_pid()
  *	update wakelock_names list for a new wakelock for a given pid
  */
-void syscall_wakelock_names_by_pid(pid_t pid, list_t *wakelock_names)
+static void syscall_wakelock_names_by_pid(pid_t pid, list_t *wakelock_names)
 {
 	link_t *l, *ln;
 
@@ -1864,7 +1864,7 @@ static char *syscall_peek_filename(const pid_t pid, const unsigned long addr)
  *  syscall_add_filename()
  *	Add filename into filename cache
  */
-void syscall_add_filename(const int syscall, const pid_t pid, const char *filename)
+static void syscall_add_filename(const int syscall, const pid_t pid, const char *filename)
 {
 	unsigned long h;
 	filename_info_t *info;
@@ -1907,8 +1907,8 @@ void syscall_add_filename(const int syscall, const pid_t pid, const char *filena
  */
 static int syscall_filename_cmp(const void *d1, const void *d2)
 {
-	filename_info_t *f1 = (filename_info_t *)d1;
-	filename_info_t *f2 = (filename_info_t *)d2;
+	const filename_info_t *f1 = (const filename_info_t *)d1;
+	const filename_info_t *f2 = (const filename_info_t *)d2;
 
 	return f2->count - f1->count;
 }
@@ -1937,7 +1937,7 @@ static void syscall_filename_cache_free(void)
  *  syscall_dump_filename()
  *	dump filename usage by syscall
  */
-void syscall_dump_filename(const char *label, const int syscall, json_object *j_obj, double duration)
+static void syscall_dump_filename(const char *label, const int syscall, json_object *j_obj, double duration)
 {
 	int i;
 	list_t sorted;
@@ -2005,7 +2005,7 @@ out:
  *  syscall_inotify_add_watch_args()
  *	trace filenames used by inotify_add_watch()
  */
-void syscall_inotify_add_watch_args(
+static void syscall_inotify_add_watch_args(
 	const syscall_t *sc,
 	const syscall_info_t *s,
 	const pid_t pid)
@@ -2040,7 +2040,7 @@ void syscall_dump_inotify(json_object *j_obj, double duration)
  *  syscall_execve_args()
  *	trace filenames used by execve()
  */
-void syscall_execve_args(
+static void syscall_execve_args(
 	const syscall_t *sc,
 	const syscall_info_t *s,
 	const pid_t pid)
@@ -2090,7 +2090,7 @@ static char *syscall_timeout_to_human_time(
 	int i;
 	double t = timeout;
 
-	for (i = 0; t != 0.0 && t < 0.99999; i++)
+	for (i = 0; !FLOAT_CMP(t, 0.0) && t < 0.99999; i++)
 		t *= 1000.0;
 
 	if (end) {
@@ -2135,11 +2135,10 @@ void syscall_dump_pollers(json_object *j_tests, const double duration)
 	}
 
 #ifdef JSON_OUTPUT
-	uint64_t poll_infinite = 0, poll_zero = 0, count = 0;
 	json_object *j_poll_test;
-	char tmp[64];
 
 	if (j_tests) {
+		uint64_t poll_infinite = 0, poll_zero = 0, count = 0;
 		json_object *j_syscall, *j_syscall_infos, *j_syscall_info;
 
 		if ((j_syscall = j_obj_new_obj()) == NULL)
@@ -2149,6 +2148,8 @@ void syscall_dump_pollers(json_object *j_tests, const double duration)
 			goto out;
 		j_obj_obj_add(j_syscall, "polling-system-calls-per-process", j_syscall_infos);
 		for (count = 0, l = sorted.head; l; l = l->next) {
+			char tmp[64];
+
 			syscall_info_t *s = (syscall_info_t *)l->data;
 			syscall_name(s->syscall, tmp, sizeof(tmp));
 			double rate = (double)s->count / duration;
